<?php
/**
 * Twenty Twenty functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage technology
 * @since Twenty Twenty 1.0
 */

/**
 * Table of Contents:
 * Theme Support
 * Required Files
 * Register Styles
 * Register Scripts
 * Register Menus
 * Custom Logo
 * WP Body Open
 * Register Sidebars
 * Enqueue Block Editor Assets
 * Enqueue Classic Editor Styles
 * Block Editor Settings
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function technology_theme_support() {

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Custom background color.
	add_theme_support(
		'custom-background',
		array(
			'default-color' => 'f5efe0',
		)
	);

	// Set content-width.
	global $content_width;
	if ( ! isset( $content_width ) ) {
		$content_width = 580;
	}

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// Set post thumbnail size.
	set_post_thumbnail_size( 1200, 9999 );

	// Add custom image size used in Cover Template.
	add_image_size( 'technology-fullscreen', 1980, 9999 );

	// Custom logo.
	$logo_width  = 120;
	$logo_height = 90;

	// If the retina setting is active, double the recommended width and height.
	if ( get_theme_mod( 'retina_logo', false ) ) {
		$logo_width  = floor( $logo_width * 2 );
		$logo_height = floor( $logo_height * 2 );
	}

	add_theme_support(
		'custom-logo',
		array(
			'height'      => $logo_height,
			'width'       => $logo_width,
			'flex-height' => true,
			'flex-width'  => true,
		)
	);

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'script',
			'style',
		)
	);

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Twenty Twenty, use a find and replace
	 * to change 'technology' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'technology' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );

	// Add support for responsive embeds.
	add_theme_support( 'responsive-embeds' );

	

}

add_action( 'after_setup_theme', 'technology_theme_support' );

/**
 * REQUIRED FILES
 * Include required files.
 */


/**
 * Register and Enqueue Styles.
 */
function technology_register_styles() {

	$theme_version = wp_get_theme()->get( 'Version' );

	wp_enqueue_style( 'technology-style', get_stylesheet_uri(), array(), $theme_version );
	wp_style_add_data( 'technology-style', 'rtl', 'replace' );

	

	// Add print CSS.
	// wp_enqueue_style( 'technology-print-style', get_template_directory_uri() . '/default.css', null, $theme_version, 'print' );

	//Add print CSS.
	// wp_enqueue_style( 'technology-print-style1', get_template_directory_uri() . '/css/animate.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style1', 'rtl', 'replace' );

	// wp_enqueue_style( 'technology-print-style2', get_template_directory_uri() . '/css/bootstrap.min.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style2', 'rtl', 'replace' );

	// wp_enqueue_style( 'technology-print-style3', get_template_directory_uri() . '/css/bootstrap-select.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style3', 'rtl', 'replace' );

	// wp_enqueue_style( 'technology-print-style4', get_template_directory_uri() . '/css/technologyousel.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style4', 'rtl', 'replace' );

	// wp_enqueue_style( 'technology-print-style5', get_template_directory_uri() . '/css/colors.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style5', 'rtl', 'replace' );

	// wp_enqueue_style( 'technology-print-style6', get_template_directory_uri() . '/css/font-awesome.min.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style6', 'rtl', 'replace' );

	// wp_enqueue_style( 'technology-print-style7', get_template_directory_uri() . '/css/responsive.css', array(), $theme_version, 'print' );
	// wp_style_add_data( 'technology-print-style7', 'rtl', 'replace' );
}

add_action( 'wp_enqueue_scripts', 'technology_register_styles' );

/**
 * Register and Enqueue Scripts.
 */
function technology_register_scripts() {

	$theme_version = wp_get_theme()->get( 'Version' );

	if ( ( ! is_admin() ) && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// wp_enqueue_script( 'technology-js', get_template_directory_uri() . '/assets/js/index.js', array(), $theme_version, false );
	// wp_script_add_data( 'technology-js', 'async', true );

	// wp_enqueue_script( 'technology-js1', get_template_directory_uri() . '/js/animate.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js1', 'async', true );

	// wp_enqueue_script( 'technology-js2', get_template_directory_uri() . '/js/bootstrap.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js2', 'async', true );

	// wp_enqueue_script( 'technology-js3', get_template_directory_uri() . '/js/bootstrap-select.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js3', 'async', true );

	// wp_enqueue_script( 'technology-js4', get_template_directory_uri() . '/js/custom.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js4', 'async', true );

	// wp_enqueue_script( 'technology-js5', get_template_directory_uri() . '/js/device.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js5', 'async', true );

	// wp_enqueue_script( 'technology-js6', get_template_directory_uri() . '/js/fitvid.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js6', 'async', true );

	// wp_enqueue_script( 'technology-js7', get_template_directory_uri() . '/js/jquery.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js7', 'async', true );

	// wp_enqueue_script( 'technology-js8', get_template_directory_uri() . '/js/owl-technologyousel.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js8', 'async', true );

	// wp_enqueue_script( 'technology-js9', get_template_directory_uri() . '/js/parallax.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js9', 'async', true );
	
	// wp_enqueue_script( 'technology-js10', get_template_directory_uri() . '/js/retina.js', array(), $theme_version, 1, 1 );
	// wp_script_add_data( 'technology-js10', 'async', true );

}

add_action( 'wp_enqueue_scripts', 'technology_register_scripts' );

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function technology_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'technology_skip_link_focus_fix' );



/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function technology_menus() {

	$locations = array(
		'primary'  => __( 'Desktop Menu', 'technology' ),
		'mobile'   => __( 'Mobile Menu', 'technology' ),
		'footer'   => __( 'Footer Menu', 'technology' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'technology_menus' );

/**
 * Get the information about the logo.
 *
 * @param string $html The HTML output from get_custom_logo (core function).
 *
 * @return string $html
 */
function technology_get_custom_logo( $html ) {

	$logo_id = get_theme_mod( 'custom_logo' );

	if ( ! $logo_id ) {
		return $html;
	}

	$logo = wp_get_attachment_image_src( $logo_id, 'full' );

	if ( $logo ) {
		// For clarity.
		$logo_width  = esc_attr( $logo[1] );
		$logo_height = esc_attr( $logo[2] );

		// If the retina logo setting is active, reduce the width/height by half.
		if ( get_theme_mod( 'retina_logo', false ) ) {
			$logo_width  = floor( $logo_width / 2 );
			$logo_height = floor( $logo_height / 2 );

			$search = array(
				'/width=\"\d+\"/iU',
				'/height=\"\d+\"/iU',
			);

			$replace = array(
				"width=\"{$logo_width}\"",
				"height=\"{$logo_height}\"",
			);

			// Add a style attribute with the height, or append the height to the style attribute if the style attribute already exists.
			if ( strpos( $html, ' style=' ) === false ) {
				$search[]  = '/(src=)/';
				$replace[] = "style=\"height: {$logo_height}px;\" src=";
			} else {
				$search[]  = '/(style="[^"]*)/';
				$replace[] = "$1 height: {$logo_height}px;";
			}

			$html = preg_replace( $search, $replace, $html );

		}
	}

	return $html;

}

add_filter( 'get_custom_logo', 'technology_get_custom_logo' );

if ( ! function_exists( 'wp_body_open' ) ) {

	/**
	 * Shim for wp_body_open, ensuring backward compatibility with versions of WordPress older than 5.2.
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}

/**
 * Include a skip to content link at the top of the page so that users can bypass the menu.
 */
function technology_skip_link() {
	echo '<a class="skip-link screen-reader-text" href="#site-content">' . __( 'Skip to the content', 'technology' ) . '</a>';
}

add_action( 'wp_body_open', 'technology_skip_link', 5 );

/**
 * Register widget areas.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function technology_sidebar_registration() {

	// Arguments used in all register_sidebar() calls.
	$shared_args = array(
		'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
		'after_title'   => '</h2>',
		'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
		'after_widget'  => '</div></div>',
	);

	// Footer #1.
	register_sidebar(
		array_merge(
			$shared_args,
			array(
				'name'        => __( 'Menu Bar Right Social', 'technology' ),
				'id'          => 'sidebar-1',
				'description' => __( 'Widgets in this area will be displayed in the first column in the footer.', 'technology' ),
			)
		)
	);

	//Footer #2.
	register_sidebar(
		array_merge(
			$shared_args,
			array(
				'name'        => __( 'Header Contact', 'technology' ),
				'id'          => 'sidebar-2',
				'description' => __( 'Widgets in this area will be displayed in the second column in the footer.', 'technology' ),
			)
		)
	);

}

add_action( 'widgets_init', 'technology_sidebar_registration' );



/**
 * Enqueue classic editor styles.
 */
function technology_classic_editor_styles() {

	$classic_editor_styles = array(
		'/assets/css/editor-style-classic.css',
	);

	add_editor_style( $classic_editor_styles );

}

add_action( 'init', 'technology_classic_editor_styles' );



/**
 * Block Editor Settings.
 * Add custom colors and font sizes to the block editor.
 */
function technology_block_editor_settings() {

	// Block Editor Palette.
	$editor_color_palette = array(
		array(
			'name'  => __( 'Accent Color', 'technology' ),
			'slug'  => 'accent',
			'color' => technology_get_color_for_area( 'content', 'accent' ),
		),
		array(
			'name'  => __( 'Primary', 'technology' ),
			'slug'  => 'primary',
			'color' => technology_get_color_for_area( 'content', 'text' ),
		),
		array(
			'name'  => __( 'Secondary', 'technology' ),
			'slug'  => 'secondary',
			'color' => technology_get_color_for_area( 'content', 'secondary' ),
		),
		array(
			'name'  => __( 'Subtle Background', 'technology' ),
			'slug'  => 'subtle-background',
			'color' => technology_get_color_for_area( 'content', 'borders' ),
		),
	);

	

	// Block Editor Font Sizes.
	add_theme_support(
		'editor-font-sizes',
		array(
			array(
				'name'      => _x( 'Small', 'Name of the small font size in the block editor', 'technology' ),
				'shortName' => _x( 'S', 'Short name of the small font size in the block editor.', 'technology' ),
				'size'      => 18,
				'slug'      => 'small',
			),
			array(
				'name'      => _x( 'Regular', 'Name of the regular font size in the block editor', 'technology' ),
				'shortName' => _x( 'M', 'Short name of the regular font size in the block editor.', 'technology' ),
				'size'      => 21,
				'slug'      => 'normal',
			),
			array(
				'name'      => _x( 'Large', 'Name of the large font size in the block editor', 'technology' ),
				'shortName' => _x( 'L', 'Short name of the large font size in the block editor.', 'technology' ),
				'size'      => 26.25,
				'slug'      => 'large',
			),
			array(
				'name'      => _x( 'Larger', 'Name of the larger font size in the block editor', 'technology' ),
				'shortName' => _x( 'XL', 'Short name of the larger font size in the block editor.', 'technology' ),
				'size'      => 32,
				'slug'      => 'larger',
			),
		)
	);

	// If we have a dark background color then add support for dark editor style.
	// We can determine if the background color is dark by checking if the text-color is white.
	if ( '#ffffff' === strtolower( technology_get_color_for_area( 'content', 'text' ) ) ) {
		add_theme_support( 'dark-editor-style' );
	}

}

add_action( 'after_setup_theme', 'technology_block_editor_settings' );

/**
 * Overwrite default more tag with styling and screen reader markup.
 *
 * @param string $html The default output HTML for the more tag.
 *
 * @return string $html
 */
function technology_read_more_tag( $html ) {
	return preg_replace( '/<a(.*)>(.*)<\/a>/iU', sprintf( '<div class="read-more-button-wrap"><a$1><span class="faux-button">$2</span> <span class="screen-reader-text">"%1$s"</span></a></div>', get_the_title( get_the_ID() ) ), $html );
}

add_filter( 'the_content_more_link', 'technology_read_more_tag' );

/**
 * Enqueues scripts for customizer controls & settings.
 *
 * @since Twenty Twenty 1.0
 *
 * @return void
 */
function technology_customize_controls_enqueue_scripts() {
	$theme_version = wp_get_theme()->get( 'Version' );

	// Add main customizer js file.
	wp_enqueue_script( 'technology-customize', get_template_directory_uri() . '/assets/js/customize.js', array( 'jquery' ), $theme_version, false );

	// Add script for color calculations.
	wp_enqueue_script( 'technology-color-calculations', get_template_directory_uri() . '/assets/js/color-calculations.js', array( 'wp-color-picker' ), $theme_version, false );

	// Add script for controls.
	wp_enqueue_script( 'technology-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls.js', array( 'technology-color-calculations', 'customize-controls', 'underscore', 'jquery' ), $theme_version, false );
	wp_localize_script( 'technology-customize-controls', 'technologyBgColors', technology_get_customizer_color_vars() );
}

add_action( 'customize_controls_enqueue_scripts', 'technology_customize_controls_enqueue_scripts' );



/**
 * Get accessible color for an area.
 *
 * @since Twenty Twenty 1.0
 *
 * @param string $area The area we want to get the colors for.
 * @param string $context Can be 'text' or 'accent'.
 * @return string Returns a HEX color.
 */
function technology_get_color_for_area( $area = 'content', $context = 'text' ) {

	// Get the value from the theme-mod.
	$settings = get_theme_mod(
		'accent_accessible_colors',
		array(
			'content'       => array(
				'text'      => '#000000',
				'accent'    => '#cd2653',
				'secondary' => '#6d6d6d',
				'borders'   => '#dcd7ca',
			),
			'header-footer' => array(
				'text'      => '#000000',
				'accent'    => '#cd2653',
				'secondary' => '#6d6d6d',
				'borders'   => '#dcd7ca',
			),
		)
	);

	// If we have a value return it.
	if ( isset( $settings[ $area ] ) && isset( $settings[ $area ][ $context ] ) ) {
		return $settings[ $area ][ $context ];
	}

	// Return false if the option doesn't exist.
	return false;
}

/**
 * Returns an array of variables for the customizer preview.
 *
 * @since Twenty Twenty 1.0
 *
 * @return array
 */
function technology_get_customizer_color_vars() {
	$colors = array(
		'content'       => array(
			'setting' => 'background_color',
		),
		'header-footer' => array(
			'setting' => 'header_footer_background_color',
		),
	);
	return $colors;
}


